(visualization)=

# Visualization

In this section you find the reference documentation of the modules contained in
the visualization module.

(visualizationvisualize)=

## visualize

```{eval-rst}
.. automodule:: visualization.visualize
   :members:
```

(visualizationlegendhandlers)=

## legend_handlers

```{eval-rst}
.. automodule:: visualization.legend_handlers
   :members:
```

(plot-array-layout)=

## plot_array_layout

```{eval-rst}
.. automodule:: visualization.plot_array_layout
   :members:
```

(plot-camera)=

## plot_camera

```{eval-rst}
.. automodule:: visualization.plot_camera
   :members:
```

## plot_corsika_histograms

(corsika-histograms-visualize-1)=

```{eval-rst}
.. automodule:: visualization.plot_corsika_histograms
   :members:
```

(plot-tables)=

## plot_tables

```{eval-rst}
.. automodule:: visualization.plot_tables
   :members:
```

## plot_pixels

```{eval-rst}
.. automodule:: visualization.plot_pixels
   :members:
```

(visualization-plot-simtel_events)=

## plot_simtel_events

```{eval-rst}
.. automodule:: visualization.plot_simtel_events
   :members:
```

(visualization-plot-simtel_event_histograms)=

## plot_simtel_event_histograms

```{eval-rst}
.. automodule:: visualization.plot_simtel_event_histograms
   :members:
```

## plot_psf

```{eval-rst}
.. automodule:: visualization.plot_psf
   :members:
```

(plot-incident-angles)=

## plot_incident_angles

```{eval-rst}
.. automodule:: visualization.plot_incident_angles

   :members:
```
